@@ -1,4 +1,6 @@
 import os
+import os.path
+import importlib
 from typing import Callable, List, Dict
 
 
@@ -95,3 +97,33 @@ def get_list_quoted(a_list: List[str]) -> str:
     s += ", ".join(quoted)
     s += "]"
     return s
+
+
+def get_package_name():
+    mod = importlib.import_module("config.python")
+    if hasattr(mod, "package_name"):
+        return getattr(mod, "package_name")
+    return os.path.basename(os.getcwd())
+
+
+def get_attr(attr: str):
+    mod = importlib.import_module("config.python")
+    if hasattr(mod, attr):
+        return getattr(mod, attr)
+    mod = importlib.import_module("default.python")
+    if hasattr(mod, attr):
+        return getattr(mod, attr)
+    # FIXME - need a better exception type (make my own)
+    raise ValueError(f"cannot find {attr}")
+
+
+def get_license_type():
+    return get_attr("license_type")
+
+
+def get_platforms():
+    return get_attr("platforms")
+
+
+def get_classifiers():
+    return get_attr("classifiers")
